import { LogLevels } from './logLevels';
export interface LogOptions {
    /**
     * This governs which logs will be written. If log level is
     * INFO all logs with INFO and above will be written. So: INFO
     * WARN and ERROR.
     */
    level?: LogLevels;
    /**
     * Sets a reference to the AWS lambda context object and will enrich the logs with context meta data to make it easier to track.
     */
    context?: AWSLambda.Context;
    /**
     * The id that came from the service that called this lambda.
     * It is best practice to send this through a header called X-REQUEST-ID.
     * In most cases you would set this to that header if it exist.
     */
    xRequestId?: string;
    /**
     * The user agent that called this service.
     * In API Gateway events it can be found here: event.headers["User-Agent"]
     */
    useragent?: string;
    /**
     * The http verb (GET|POST...)
     * * In API Gateway events it can be found here: event.httpMethod
     */
    verb?: string;
    /**
     * The host of this service.
     * * In API Gateway events it can be found here: event.headers["Host"]
     */
    host?: string;
    /**
     * The http path of this service.
     * * In API Gateway events it can be found here: event.path
     */
    path?: string;
    /**
     * The host of this service.
     * * In API Gateway events it can be found here: event.queryStringParameters
     */
    query?: any;
}
