export interface LogOutput {
    /**
     * AWS request ID associated with the request. This is the ID returned to the client that called the invoke method.
     */
    'awsRequestId': string | undefined;
    /**
     * The time this was logged in ticks.
     */
    '@timestamp': number;
    /**
     * The actual log message, please make this a non
     */
    'message': string;
    /**
     * The log level
     */
    'level': string;
    /**
     * The id that came from the service that called this lambda.
     * It is best practice to send this through a header called X-REQUEST-ID.
     * In most cases you would set this to that header if it exist.
     */
    'xRequestId': string | undefined;
    /**
     * Name of the Lambda function that is executing.
     */
    'functionName': string | undefined;
    /**
     * Time time that this lambda has been up.
     */
    'invokedFunctionArn': string | undefined;
    /**
     * Time time that this lambda has been up.
     */
    'memoryLimitInMB': number | undefined;
    /**
     * Time time remaining before this lambda execution shuts down.
     */
    'remainingTime': number | undefined;
    /**
     * The user agent that called this service.
     * In API Gateway events it can be found here: event.headers["User-Agent"]
     */
    'useragent'?: string | undefined;
    /**
     * The host of this service.
     * * In API Gateway events it can be found here: event.headers["Host"]
     */
    'host'?: string | undefined;
    /**
     * The host of this service.
     * * In API Gateway events it can be found here: event.queryStringParameters
     */
    'query'?: any | undefined;
    /**
     * The http path of this service.
     * * In API Gateway events it can be found here: event.path
     */
    'path'?: string | undefined;
    /**
     * The http verb (GET|POST...)
     * * In API Gateway events it can be found here: event.httpMethod
     */
    'verb'?: string | undefined;
    /**
     * Call stack, typically used for when errors occur.
     */
    'stack': string;
    [x: string]: any;
}
